def eval(script :str) -> object:
	"""
	执行JS片段。
	"""
	pass
def exec_file(filePath :str) -> object:
	"""
	执行JS脚本。
	"""
	pass
def rmi(addr :str) -> object:
	"""
	连接JSRMI服务。
	"""
	pass
class JSRMI:
	def close(self) -> object:
		"""
		关闭连接。
		"""
		pass
	def eval(self,cmd :str) -> object:
		"""
		执行命令。
		"""
		pass
	pass