def base64_decode(data :str) -> object:
	"""
	Base64解码。
	"""
	pass
def gzip_decode(data :object) -> object:
	"""
	Gzip解码。
	"""
	pass
def json_loads(data :str) -> object:
	"""
	加载并解析Json字符串。
	"""
	pass
def wxapkg_decode(wxid :str,data :str) -> object:
	"""
	WXApkg解码。
	"""
	pass
def md5(s :str) -> str:
	"""
	计算字符串的md5值
	"""
	pass
def url_encode(urlStr :str) -> str:
	"""
	URL编码。
	"""
	pass
def gzip_encode(data :str) -> object:
	"""
	Gzip编码。
	"""
	pass
def json_dumps(a :object) -> str:
	"""
	将一个对象序列化为Json字符串。
	"""
	pass
def url_decode(urlStr :str) -> str:
	"""
	URL解码。
	"""
	pass
def base64_encode(data :str) -> str:
	"""
	Base64编码。
	"""
	pass