GREEN= None #绿色
BLUE= None #蓝色
YELLOW= None #黄色
RFC1123Z= None #Mon, 02 Jan 2006 15:04:05 -0700
def echo(text :object,color :object,end :object) -> object:
	"""
	带有颜色的print，会打印解释器内部的结构。
	"""
	pass
def bytes(data :object) -> object:
	"""
	转换数据类型为bytes。
	"""
	pass
def parse_time(layout :str,value :str) -> object:
	"""
	解析时间字符串，返回Unix时间戳。
	"""
	pass
RFC3339Nano= None #2006-01-02T15:04:05.999999999Z07:00
RFC822Z= None #02 Jan 06 15:04 -0700
RFC850= None #Monday, 02-Jan-06 15:04:05 MST
def input(prefix :str,color :object,title :str,history :object,completer :object) -> str:
	"""
	支持补全的输入。
	"""
	pass
GRAY= None #灰色
CYAN= None #青色
WHITE= None #白色
RFC3339= None #2006-01-02T15:04:05Z07:00
RFC822= None #02 Jan 06 15:04 MST
def render(parts :object) -> str:
	"""
	按照“颜色、字符串、颜色、字符串……“的循环模式生成多彩的字符串。
	"""
	pass
def string(data :object) -> str:
	"""
	转换数据类型为string。
	"""
	pass
def random_num(max :int) -> int:
	"""
	生成从0到指定最大值的随机数。
	"""
	pass
RED= None #红色
BLACK= None #黑色
MAGENTA= None #洋红色
RFC1123= None #Mon, 02 Jan 2006 15:04:05 MST